2021-11-23 Version: 2.0.1
- Add Create Savingplan Instance API.

2021-08-12 Version: 1.0.8
- Generated python 2017-12-14 for BssOpenApi.

2021-06-25 Version: 1.0.7
- AMP Version Change.

2021-06-15 Version: 1.0.6
- AMP Version Change.

2021-04-28 Version: 1.0.5
- AMP Version Change.

2021-03-26 Version: 1.0.4
- AMP Version Change.

2021-03-23 Version: 1.0.3
- Generated python 2017-12-14 for BssOpenApi.

2021-03-19 Version: 1.0.2
- AMP Version Change.

2021-03-04 Version: 1.0.1
- AMP Version Change.

2021-02-04 Version: 0.1.3
- Add FinancialRelationApi to support for multie enterprise financial account query.

2021-01-27 Version: 1.0.0
- Generated python 2017-12-14 for BssOpenApi.

2021-01-19 Version: 0.1.2
- Generated python 2017-12-14 for BssOpenApi.

2020-09-24 Version: 0.1.1
- Supported query account transactions.

